pub struct MultisigClientBuilder { /* private fields */ }Expand description
Builder for constructing MultisigClient instances.
Example
use miden_multisig_client::MultisigClient;
use miden_client::rpc::Endpoint;
let client = MultisigClient::builder()
.miden_endpoint(Endpoint::new("http://localhost:57291"))
.guardian_endpoint("http://localhost:50051")
.account_dir("/tmp/multisig-client")
.prover_config(
miden_multisig_client::ProverConfig::new()
.with_url("https://prover.example")?
.with_retry_policy(miden_multisig_client::ProverRetryPolicy::new(4)),
)
.generate_key()
.build()
.await?;Implementations
Sourceimpl MultisigClientBuilder
impl MultisigClientBuilder
Sourcepub fn miden_endpoint(self, endpoint: Endpoint) -> Self
pub fn miden_endpoint(self, endpoint: Endpoint) -> Self
Sets the Miden node RPC endpoint.
Sourcepub fn note_transport_endpoint(self, endpoint: impl Into<String>) -> Self
pub fn note_transport_endpoint(self, endpoint: impl Into<String>) -> Self
Sets the note transport service endpoint used for private note relay.
Overrides the default derived from the Miden endpoint (the public transport services for the testnet and devnet presets). A custom Miden node endpoint has no derivable transport service, so this is the only way to enable note transport there.
Sourcepub fn guardian_endpoint(self, endpoint: impl Into<String>) -> Self
pub fn guardian_endpoint(self, endpoint: impl Into<String>) -> Self
Sets the GUARDIAN server endpoint.
Sourcepub fn prover_config(self, prover_config: ProverConfig) -> Self
pub fn prover_config(self, prover_config: ProverConfig) -> Self
Configures the remote transaction prover and its retry policy.
Sourcepub fn rpc_config(self, rpc_config: RpcConfig) -> Self
pub fn rpc_config(self, rpc_config: RpcConfig) -> Self
Configures the Miden node RPC timeout and idempotent-read retry policy.
Sourcepub fn account_dir(self, path: impl Into<PathBuf>) -> Self
pub fn account_dir(self, path: impl Into<PathBuf>) -> Self
Sets the account directory for miden-client storage.
This directory will contain the SQLite database for account and transaction data.
Sourcepub fn key_manager(self, key_manager: Box<dyn KeyManager>) -> Self
pub fn key_manager(self, key_manager: Box<dyn KeyManager>) -> Self
Sets a custom key manager for GUARDIAN authentication and proposal signing.
Sourcepub fn with_secret_key(self, secret_key: SecretKey) -> Self
pub fn with_secret_key(self, secret_key: SecretKey) -> Self
Uses a FalconKeyStore with the given secret key.
Sourcepub fn with_ecdsa_secret_key(self, secret_key: EcdsaSecretKey) -> Self
pub fn with_ecdsa_secret_key(self, secret_key: EcdsaSecretKey) -> Self
Uses an ECDSA key store with the given secret key.
Sourcepub fn generate_key(self) -> Self
pub fn generate_key(self) -> Self
Generates a new random key for GUARDIAN authentication.
Sourcepub fn generate_ecdsa_key(self) -> Self
pub fn generate_ecdsa_key(self) -> Self
Generates a new random ECDSA key for GUARDIAN authentication.
Sourcepub async fn build(self) -> Result<MultisigClient>
pub async fn build(self) -> Result<MultisigClient>
Builds the MultisigClient.